<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Overwrite parent theme background defaults and registers support for WordPress features.
add_action( 'after_setup_theme', 'lalita_background_setup' );
function lalita_background_setup() {
	add_theme_support( "custom-background",
		array(
			'default-color' 		 => '0845ec',
			'default-image'          => '',
			'default-repeat'         => 'repeat',
			'default-position-x'     => 'left',
			'default-position-y'     => 'top',
			'default-size'           => 'auto',
			'default-attachment'     => '',
			'wp-head-callback'       => '_custom_background_cb',
			'admin-head-callback'    => '',
			'admin-preview-callback' => ''
		)
	);
}

// Overwrite theme URL
function lalita_theme_uri_link() {
	return 'https://wpkoi.com/neela-wpkoi-wordpress-theme/';
}

// Overwrite parent theme's blog header function
add_action( 'lalita_after_header', 'lalita_blog_header_image', 11 );
function lalita_blog_header_image() {

	if ( ( is_front_page() && is_home() ) || ( is_home() ) ) { 
		$blog_header_image =  lalita_get_setting( 'blog_header_image' ); 
			$blog_header_title =  lalita_get_setting( 'blog_header_title' ); 
			$blog_header_text =  lalita_get_setting( 'blog_header_text' ); 
			$blog_header_button_text =  lalita_get_setting( 'blog_header_button_text' ); 
			$blog_header_button_url =  lalita_get_setting( 'blog_header_button_url' ); 
			if ( $blog_header_image != '' ) { ?>
			<div class="page-header-image grid-parent page-header-blog" style="background-image: url(<?php echo esc_url($blog_header_image); ?>)">
                <div class="page-header-blog-inner">
                    <div class="page-header-blog-content-h grid-container">
                        <div class="page-header-blog-content">
                        <?php if ( ( $blog_header_title != '' ) || ( $blog_header_title != '' ) ) { ?>
                            <?php if ( $blog_header_title != '' ) { ?>
                            <h2><?php echo wp_kses_post( $blog_header_title ); ?></h2>
                            <div class="clearfix"></div>
                            <?php } ?>
                            <?php if ( $blog_header_title != '' ) { ?>
                            <p><?php echo wp_kses_post( $blog_header_text ); ?></p>
                            <div class="clearfix"></div>
                            <?php } ?>
                            <?php if ( $blog_header_button_text != '' ) { ?>
                            <a class="read-more button" href="<?php echo esc_url( $blog_header_button_url ); ?>"><?php echo esc_html( $blog_header_button_text ); ?></a>
                            <?php } ?>
                        <?php } ?>
                        </div>
                    </div>
                </div>
			</div>
			<?php
		}
	}
}

// Extra cutomizer functions
if ( ! function_exists( 'neela_customize_register' ) ) {
	add_action( 'customize_register', 'neela_customize_register' );
	function neela_customize_register( $wp_customize ) {
				
		// Add Neela customizer section
		$wp_customize->add_section(
			'neela_layout_effects',
			array(
				'title' => __( 'Neela Effects', 'neela' ),
				'priority' => 24,
			)
		);
		
		
		// Logo effect
		$wp_customize->add_setting(
			'neela_settings[logo_effect]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'neela_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'neela_settings[logo_effect]',
			array(
				'type' => 'select',
				'label' => __( 'Logo effect', 'neela' ),
				'choices' => array(
					'enable' => __( 'Enable', 'neela' ),
					'disable' => __( 'Disable', 'neela' )
				),
				'settings' => 'neela_settings[logo_effect]',
				'section' => 'neela_layout_effects',
				'priority' => 1
			)
		);
		
		// Cursor
		$wp_customize->add_setting(
			'neela_settings[cursor]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'neela_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'neela_settings[cursor]',
			array(
				'type' => 'select',
				'label' => __( 'Cursor', 'neela' ),
				'choices' => array(
					'enable' => __( 'Enable', 'neela' ),
					'disable' => __( 'Disable', 'neela' )
				),
				'settings' => 'neela_settings[cursor]',
				'section' => 'neela_layout_effects',
				'priority' => 3
			)
		);
		
		// Blog title effect
		$wp_customize->add_setting(
			'neela_settings[blog_title_effect]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'neela_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'neela_settings[blog_title_effect]',
			array(
				'type' => 'select',
				'label' => __( 'Blog title effect', 'neela' ),
				'choices' => array(
					'enable' => __( 'Enable', 'neela' ),
					'disable' => __( 'Disable', 'neela' )
				),
				'settings' => 'neela_settings[blog_title_effect]',
				'section' => 'neela_layout_effects',
				'priority' => 2
			)
		);
		
		// Nicescroll
		$wp_customize->add_setting(
			'neela_settings[nicescroll]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'neela_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'neela_settings[nicescroll]',
			array(
				'type' => 'select',
				'label' => __( 'Neela scrollbar style', 'neela' ),
				'choices' => array(
					'enable' => __( 'Enable', 'neela' ),
					'disable' => __( 'Disable', 'neela' )
				),
				'settings' => 'neela_settings[nicescroll]',
				'section' => 'neela_layout_effects',
				'priority' => 8
			)
		);
		
	}
}

//Sanitize choices.
if ( ! function_exists( 'neela_sanitize_choices' ) ) {
	function neela_sanitize_choices( $input, $setting ) {
		// Ensure input is a slug
		$input = sanitize_key( $input );

		// Get list of choices from the control
		// associated with the setting
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it;
		// otherwise, return the default
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
}

// Neela effects colors css
if ( ! function_exists( 'neela_effect_colors_css' ) ) {
	function neela_effect_colors_css() {
		// Get our settings from parent theme
		$lalita_settings = wp_parse_args(
			get_option( 'lalita_settings', array() ),
			lalita_get_color_defaults()
		);
		
		$neela_extracolors = '.page-header-blog-content h2{color: ' . esc_attr( $lalita_settings[ 'blog_header_text_color' ] ) . ';background-color: ' . esc_attr( $lalita_settings[ 'blog_header_title_color' ] ) . ';text-shadow: ' . esc_attr( $lalita_settings[ 'blog_header_bg_s_color' ] ) . '}.page-header-blog-content p{color: ' . esc_attr( $lalita_settings[ 'blog_header_title_color' ] ) . ';background-color: ' . esc_attr( $lalita_settings[ 'blog_header_text_color' ] ) . ';}.neela-logo-effect .main-title a::after {background-image: repeating-linear-gradient( 135deg, transparent 0, transparent 2px, ' . esc_attr( $lalita_settings[ 'navigation_text_color' ] ) . ' 2px, ' . esc_attr( $lalita_settings[ 'navigation_text_color' ] ) . ' 3px );} .neela-logo-effect .main-title a::before {background-image: repeating-linear-gradient( 45deg, transparent 0, transparent 2px, ' . esc_attr( $lalita_settings[ 'navigation_text_color' ] ) . ' 2px, ' . esc_attr( $lalita_settings[ 'navigation_text_color' ] ) . ' 3px );} .neela-logo-effect .main-title a::before, .neela-logo-effect .main-title a::after {content: "' . esc_attr( get_bloginfo( 'name' ) ) . '";}.neela-blog-title-effect article .entry-header .entry-title a {background-image: linear-gradient(transparent calc(65% - 5px), ' . esc_attr( $lalita_settings[ 'blog_header_title_color' ] ) . ' 5px);}';
		
		return $neela_extracolors;
	}
}


// The dynamic styles of the parent theme added inline to the parent stylesheet.
// For the customizer functions it is better to enqueue after the child theme stylesheet.
if ( ! function_exists( 'neela_remove_parent_dynamic_css' ) ) {
	add_action( 'init', 'neela_remove_parent_dynamic_css' );
	function neela_remove_parent_dynamic_css() {
		remove_action( 'wp_enqueue_scripts', 'lalita_enqueue_dynamic_css', 50 );
	}
}

// Enqueue this CSS after the child stylesheet, not after the parent stylesheet.
if ( ! function_exists( 'neela_enqueue_parent_dynamic_css' ) ) {
	add_action( 'wp_enqueue_scripts', 'neela_enqueue_parent_dynamic_css', 50 );
	function neela_enqueue_parent_dynamic_css() {
		$css = lalita_base_css() . lalita_font_css() . lalita_advanced_css() . lalita_spacing_css() . lalita_no_cache_dynamic_css() .neela_effect_colors_css();

		// escaped secure before in parent theme
		wp_add_inline_style( 'lalita-child', $css );
	}
}

//Adds custom classes to the array of body classes.
if ( ! function_exists( 'neela_body_classes' ) ) {
	add_filter( 'body_class', 'neela_body_classes' );
	function neela_body_classes( $classes ) {
		// Get Customizer settings
		$neela_settings = get_option( 'neela_settings' );
		
		$logo_effect 	   = 'enable';
		$blog_title_effect = 'enable';
		$cursor  	   	   = 'enable';
		$nicescroll  	   = 'enable';
		
		if ( isset( $neela_settings['logo_effect'] ) ) {
			$logo_effect = $neela_settings['logo_effect'];
		}
		
		if ( isset( $neela_settings['blog_title_effect'] ) ) {
			$blog_title_effect = $neela_settings['blog_title_effect'];
		}
		
		if ( isset( $neela_settings['cursor'] ) ) {
			$cursor = $neela_settings['cursor'];
		}
		
		if ( isset( $neela_settings['nicescroll'] ) ) {
			$nicescroll = $neela_settings['nicescroll'];
		}
		
		// Logo effect
		if ( $logo_effect != 'disable' ) {
			$classes[] = 'neela-logo-effect';
		}
		
		// Blog title effect
		if ( $blog_title_effect != 'disable' ) {
			$classes[] = 'neela-blog-title-effect';
		}
		
		// Cursor
		if ( $cursor != 'disable' ) {
			$classes[] = 'neela-cursor-style';
		}
		
		// Scrollbar style function
		if ( $nicescroll != 'disable' ) {
			$classes[] = 'neela-scrollbar-style';
		}
		
		return $classes;
	}
}

if ( ! function_exists( 'neela_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'neela_scripts' );
	/**
	 * Enqueue script
	 */
	function neela_scripts() {
		
		$neela_settings = get_option( 'neela_settings' );
		
		$cursor		 = 'enable';
		if ( isset( $neela_settings['cursor'] ) ) {
			$cursor = $neela_settings['cursor'];
		}
		
		if ( $cursor != 'disable' ) {
			wp_enqueue_style( 'neela-magic-mouse', esc_url( get_stylesheet_directory_uri() ) . "/css/magic-mouse.min.css", false, LALITA_VERSION, 'all' );
			wp_enqueue_script( 'neela-magic-mouse', esc_url( get_stylesheet_directory_uri() ) . "/js/magic-mouse.min.js", array( 'jquery'), LALITA_VERSION, true );
		}
		
	}
}